@@ -29,12 +29,11 @@
 #include <QVBoxLayout>
 #include <QTimer> // Next Level after N seconds
 #include <kmessagebox.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
+#include <KLocalizedString>
 #include <kconfig.h>
-#include <kglobalsettings.h>
-#include <kfiledialog.h>
-#include <kdebug.h>
+#include <qfiledialog.h>
+#include <QDebug>
+#include <QUrl>
 
 GameWidget::GameWidget ( const QString& levelSet, QWidget *parent )
     : QWidget( parent ), m_allowAnyLevelSwitch( false ), m_moves(0), m_level(0)
@@ -66,13 +65,13 @@ GameWidget::GameWidget ( const QString& levelSet, QWidget *parent )
 
     top->addWidget(m_view, 1);
 
-    connect (m_playField, SIGNAL (gameOver(int)), SLOT(gameOver(int)));
-    connect (m_playField, SIGNAL (updateMoves(int)), SLOT(updateMoves(int)));
+    connect(m_playField, &PlayField::gameOver, this, &GameWidget::gameOver);
+    connect(m_playField, &PlayField::updateMoves, this, &GameWidget::updateMoves);
 
     // Next level after some seconds after ending the game. See gameOver, nextLevel and prevLevel
     m_timer = new QTimer(this);
     m_timer->setSingleShot(true);
-    connect (m_timer, SIGNAL(timeout()), this, SLOT(nextLevel()));
+    connect(m_timer, &QTimer::timeout, this, &GameWidget::nextLevel);
 
     setLevelSet(levelSet);
 }
@@ -87,7 +86,7 @@ bool GameWidget::setLevelSet(const QString& levelSet)
 {
     if (m_levelSet.name() == levelSet)
     {
-        kDebug() << "level set named" << levelSet << "is already loaded";
+        //qDebug() << "level set named" << levelSet << "is already loaded";
         return true;
     }
 
@@ -95,7 +94,7 @@ bool GameWidget::setLevelSet(const QString& levelSet)
     if (!res)
     {
         KMessageBox::error(this, i18n("Failed to load level set \"%1\". Check if it is installed on your computer.", levelSet));
-        kDebug() << "failed to load levelset" << levelSet;
+        //qDebug() << "failed to load levelset" << levelSet;
         return false;
     }
 
@@ -190,8 +189,9 @@ void GameWidget::switchToLevel (int l)
 
         saveLastPlayedLevel();
     }
-    else
-        kDebug() << "failed to load level" << l;
+    else {
+        //qDebug() << "failed to load level" << l;
+    }
 }
 
 void GameWidget::restartLevel()
@@ -201,7 +201,7 @@ void GameWidget::restartLevel()
 
 void GameWidget::saveGame()
 {
-    QString fileName = KFileDialog::getSaveFileName( KUrl(), "*.katomic", this );
+    QString fileName = QFileDialog::getSaveFileName( this, QString(), QString(), "*.katomic" );
     if(fileName.isEmpty())
         return;
     KConfig config(fileName, KConfig::SimpleConfig);
@@ -213,7 +213,7 @@ void GameWidget::saveGame()
 
 void GameWidget::loadGame()
 {
-    QString fileName = KFileDialog::getOpenFileName( KUrl(), "*.katomic", this );
+    QString fileName = QFileDialog::getOpenFileName( this, QString(), QString(), "*.katomic" );
     if(fileName.isEmpty())
         return;
     KConfig config(fileName, KConfig::SimpleConfig);
@@ -221,7 +221,7 @@ void GameWidget::loadGame()
     QString levelSet = gr.readEntry("LevelSet");
     if (levelSet.isEmpty())
     {
-        kDebug() << "note: savegame file doesn't contain info about levelset, assuming default one";
+        //qDebug() << "note: savegame file doesn't contain info about levelset, assuming default one";
         levelSet = DEFAULT_LEVELSET_NAME;
     }
 
@@ -275,7 +275,7 @@ void GameWidget::resizeEvent( QResizeEvent* ev)
 
 void GameWidget::saveLastPlayedLevel()
 {
-    KSharedConfigPtr cfg = KGlobal::config();
+    KSharedConfigPtr cfg = KSharedConfig::openConfig();
     KConfigGroup grp(cfg, m_levelSet.name());
     grp.writeEntry("LastPlayedLevel", m_level);
 
@@ -284,27 +284,27 @@ void GameWidget::saveLastPlayedLevel()
 
 void GameWidget::saveMaxAccessibleLevel(int level)
 {
-    KSharedConfigPtr cfg = KGlobal::config();
+    KSharedConfigPtr cfg = KSharedConfig::openConfig();
     KConfigGroup grp(cfg, m_levelSet.name());
     grp.writeEntry("MaxAccessibleLevel", level);
 }
 
 int GameWidget::lastPlayedLevel() const
 {
-    KSharedConfigPtr cfg = KGlobal::config();
+    KSharedConfigPtr cfg = KSharedConfig::openConfig();
     KConfigGroup grp(cfg, m_levelSet.name());
     int lastPlayed = grp.readEntry("LastPlayedLevel", 1);
     lastPlayed = qMax(1, lastPlayed); // can't be less than 1
-    kDebug() << "last played level:" << lastPlayed;
+    //qDebug() << "last played level:" << lastPlayed;
     return lastPlayed;
 }
 
 int GameWidget::maxAccessibleLevel() const
 {
-    KSharedConfigPtr cfg = KGlobal::config();
+    KSharedConfigPtr cfg = KSharedConfig::openConfig();
     KConfigGroup grp(cfg, m_levelSet.name());
     int maxAccessible = grp.readEntry("MaxAccessibleLevel", 1);
-    kDebug() << "max accessible level:" << maxAccessible;
+    //qDebug() << "max accessible level:" << maxAccessible;
     return maxAccessible;
 }
 
@@ -320,4 +320,4 @@ bool GameWidget::isPrevLevelAvailable() const
     return m_level > 1;
 }
 
-#include "gamewidget.moc"
+
